@@ -14,6 +14,19 @@ setMethod("getInfRobIC", signature(L2deriv = "UnivariateDistribution",
         biastype <- biastype(risk)
         radius <- neighbor@radius
 
+        p <- nrow(trafo)
+        k <- ncol(trafo)
+
+        ## non-standard norms
+        FI <- solve(trafo%*%matrix(1/Finfo,1,1)%*%t(trafo))
+        if(is(normtype,"InfoNorm") || is(normtype,"SelfNorm") ){
+           QuadForm(normtype) <- PosSemDefSymmMatrix(FI)
+           normtype(risk) <- normtype
+        }
+        std <- if(is(normtype,"QFNorm"))
+                  QuadForm(normtype) else diag(p)
+        FI0 <- sum(diag(std%*%as.matrix(FI)))
+
         if(identical(all.equal(radius, 0), TRUE)){
             if(warn) cat("'radius == 0' => (classical) optimal IC\n", 
                          "in sense of Cramer-Rao bound is returned\n")
@@ -23,8 +36,9 @@ setMethod("getInfRobIC", signature(L2deriv = "UnivariateDistribution",
             res <- c(res, list(biastype = biastype, normtype = NormType()))
             if(!is(risk, "asMSE")){
                 Risk <- getAsRisk(risk = risk, L2deriv = L2deriv, neighbor = neighbor, 
-                                  biastype = biastype, clip = res$b, cent = res$a, 
-                                  stand = res$A, trafo = trafo)
+                                  biastype = biastype, normtype = normtype, 
+                                  clip = res$b, cent = res$a, 
+                                  stand = res$A, trafo = trafo, FI = FI0)
                 res$risk <- c(Risk, res$risk)
             }
             Cov <- res$risk$asCov
@@ -52,6 +66,7 @@ setMethod("getInfRobIC", signature(L2deriv = "UnivariateDistribution",
             z.old <- z
             c0.old <- c0
             ## new
+            if(is(risk,"asMSE")){
             L1n <- getL1normL2deriv(L2deriv = L2deriv, cent = z)
             lower0 <-  L1n/(1 + radius^2)
 #            if(is(neighbor,"TotalVarNeighborhood")) {
@@ -67,6 +82,10 @@ setMethod("getInfRobIC", signature(L2deriv = "UnivariateDistribution",
 ##            print(c(lower,upper))
             #lower <- 0; upper <- 100
             ##
+            }else{
+              if(is.null(lower)) lower <- 10^-9
+              if(is.null(upper)) upper <- 40
+            }
             c0 <- try(uniroot(getInfClip, 
                   ## new
                         lower = lower, upper = upper,
@@ -87,8 +106,9 @@ setMethod("getInfRobIC", signature(L2deriv = "UnivariateDistribution",
                                 maxiter = maxiter, tol = tol, warn = warn,
                                 verbose = verbose)
                 Risk <- getAsRisk(risk = risk, L2deriv = L2deriv, neighbor = neighbor, 
-                                  biastype = biastype,  clip = res$b, cent = res$a, 
-                                  stand = res$A, trafo = trafo)
+                                  biastype = biastype,  normtype = normtype, 
+                                  clip = res$b, cent = res$a, 
+                                  stand = res$A, trafo = trafo, FI = FI0)
                 res$risk <- c(Risk, res$risk)
                 return(res)
             }
@@ -126,8 +146,9 @@ setMethod("getInfRobIC", signature(L2deriv = "UnivariateDistribution",
         b <- abs(as.vector(A))*c0
         if(!is(risk, "asMSE")){
             Risk <- getAsRisk(risk = risk, L2deriv = L2deriv, neighbor = neighbor, 
-                              biastype = biastype, clip = b, cent = a, stand = A, 
-                              trafo = trafo)
+                              biastype = biastype, normtype = normtype, 
+                              clip = b, cent = a, stand = A, 
+                              trafo = trafo, FI = FI0)
         }else{
             Risk <- NULL
         }
@@ -201,6 +222,7 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
         }
         std <- if(is(normtype,"QFNorm"))
                   QuadForm(normtype) else diag(p)
+        FI0 <- sum(diag(std%*%as.matrix(FI)))
 
         ## starting values
         if(is.null(z.start)) z.start <- numeric(k)
@@ -256,7 +278,8 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
                                    L2derivDistrSymm = L2derivDistrSymm,
                                    z.start = z.start, A.start = A.start,
                                    trafo = trafo, maxiter = maxiter, tol = tol,
-                                   warn = FALSE, Finfo = Finfo, verbose = verbose)
+                                   warn = FALSE, Finfo = Finfo, QuadForm = std, 
+                                   verbose = verbose)
                lower <- lowBerg$b}
             #if(is.null(upper))
                upper <- 5*max(solve(Finfo))
@@ -288,6 +311,11 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
             biastype <- erg$biastype
             normtype.old <- erg$normtype.old
             normtype <- erg$normtype
+
+            std.n <- if(is(normtype,"QFNorm"))
+                  QuadForm(normtype) else diag(p)
+            FI0 <- sum(diag(std.n%*%as.matrix(FI)))
+
             risk <- erg$risk
             iter <- erg$iter
             prec <- prec.In <- iter.In <- NULL
@@ -298,8 +326,9 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
 
             if(!is(risk, "asMSE")){
                    Risk <- getAsRisk(risk = risk, L2deriv = L2deriv, neighbor = neighbor,
-                                     biastype = biastype, clip = b, cent = a, stand = A,
-                                     trafo = trafo)
+                                     biastype = biastype, normtype = normtype, 
+                                     clip = b, cent = a, stand = A,
+                                     trafo = trafo, FI = FI0)
             }else{
                    Risk <- sum(diag(std%*%Cov)) + radius^2 * b^2
             }
@@ -343,7 +372,8 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
                                        L2derivDistrSymm = L2derivDistrSymm,
                                        z.start = z.start, A.start = A.start,
                                        trafo = trafo, maxiter = maxiter, tol = tol,
-                                       warn = warn, Finfo = Finfo, verbose = verbose)
+                                       warn = warn, Finfo = Finfo, QuadForm = std, 
+                                       verbose = verbose)
                            )
 
                 maxit2 <- if(OptOrIter==2) 0 else maxiter
@@ -369,6 +399,7 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
                  OptIterCall <- erg$call
                  std <- if(is.null(erg$std)) std else erg$std
 #                 print(list(z=z,A=A,b=b))
+                 FI0 <- sum(diag(std%*%as.matrix(FI)))
 
 
                  ## check precision and number of iterations in outer b-loop
@@ -418,8 +449,9 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
           if(verbose && withPICcheck) print(list(Cov=Cov,A=A,a=a,w=w))
           if(!is(risk, "asMSE")){
               Risk <- getAsRisk(risk = risk, L2deriv = L2deriv, neighbor = neighbor,
-                                biastype = biastype, clip = b, cent = a, stand = A,
-                                trafo = trafo)
+                                biastype = biastype, normtype = normtype, 
+                                clip = b, cent = a, stand = A,
+                                trafo = trafo, FI = FI0)
           }else{
               Risk <- NULL
           }
@@ -464,9 +496,12 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
                                QuadForm = QuadForm, verbose = verbose)
             res <- c(res, list(biastype = biastype, normtype = normtype))
             if(!is(risk, "asMSE")){
+                    FI <- trafo%*%solve(Finfo)%*%t(trafo)
+                    FI <- sum(diag(QuadForm %*% FI))
                 Risk <- getAsRisk(risk = risk, L2deriv = L2deriv, neighbor = neighbor,
-                                  biastype = biastype, cent = res$a,
-                                  stand = res$A, trafo = trafo)
+                                  biastype = biastype, normtype = normtype, 
+                                  cent = res$a, stand = res$A, trafo = trafo,
+                                  FI = FI)
                 res$risk <- c(Risk, res$risk)
             }
             trAsCov <- sum(diag(QuadForm%*%res$risk$asCov));
@@ -484,7 +519,7 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
 .getLowerSol  <- function(L2deriv, risk, neighbor, Distr, DistrSymm,
                          L2derivSymm, L2derivDistrSymm,
                          z.start, A.start, trafo,
-                         maxiter, tol, warn, Finfo, verbose){
+                         maxiter, tol, warn, Finfo, QuadForm, verbose){
                 if(warn) cat("Could not determine optimal clipping bound!\n",
                              "'radius >= maximum radius' for the given risk?\n",
                              "=> the minimum asymptotic bias (lower case) solution is returned\n",
@@ -500,9 +535,12 @@ setMethod("getInfRobIC", signature(L2deriv = "RealRandVariable",
                                    verbose = verbose)
                 normtype(risk) <- res$normtype
                 if(!is(risk, "asMSE")){
+                    FI <- trafo%*%solve(Finfo)%*%t(trafo)
+                    FI <- sum(diag(QuadForm %*% FI))
                     Risk <- getAsRisk(risk = risk, L2deriv = L2deriv, neighbor = neighbor,
-                                      biastype = biastype, clip = NULL,
-                                      cent = res$a, stand = res$A, trafo = trafo)
+                                      biastype = biastype(risk), normtype = normtype(risk),
+                                      clip = NULL, cent = res$a, stand = res$A, Distr = Distr, 
+                                      FI = FI,w = res$w)
                     res$risk <- c(Risk, res$risk)
                 }
                 return(res)
